from setuptools import setup

setup(
    name='ML-Algo',
    version='1.2.2',
    author='Mr Raj',
    author_email='arunraj14092002@gmail.com',
    description='A package for calculating Series Time Data',
    packages=['ML_Algo'],
    install_requires=['pandas'],
)